cytoflow.utility.logicle_ext package
====================================

Submodules
----------

cytoflow.utility.logicle_ext.Logicle module
-------------------------------------------

.. automodule:: cytoflow.utility.logicle_ext.Logicle
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cytoflow.utility.logicle_ext
    :members:
    :undoc-members:
    :show-inheritance:
